@@ -242,25 +242,25 @@ class LogicExpression(object):
 
     def calculate(self, n1, n2, op, context):
         if op == '|':
-            if context.get(self.expression_dict[n1]):
+            if (isinstance(n1, bool) and n1 is True) or (not isinstance(n1, bool) and context.get(self.expression_dict[n1])):
                 return True
 
-            if context.get(self.expression_dict[n2]):
+            if (isinstance(n2, bool) and n2 is True) or (not isinstance(n2, bool) and context.get(self.expression_dict[n2])):
                 return True
             else:
                 return False
 
         if op == '&':
-            if not context.get(self.expression_dict[n1]):
+            if (isinstance(n1, bool) and n1 is False) or (not isinstance(n1, bool) and not context.get(self.expression_dict[n1])):
                 return False
 
-            if not context.get(self.expression_dict[n2]):
+            if (isinstance(n2, bool) and n2 is False) or (not isinstance(n2, bool) and not context.get(self.expression_dict[n2])):
                 return False
             else:
                 return True
 
     def calculate_not(self, n, context):
-        if context.get(self.expression_dict[n]):
+        if (isinstance(n, bool) and n is True) or (not isinstance(n, bool) and context.get(self.expression_dict[n])):
             return False
         else:
             return True
@@ -300,7 +300,7 @@ class LogicExpression(object):
 
 
 if __name__ == "__main__":
-    text = "11B"
+    text = "(1A&2B)|1B"
 
     lexer = Lexer(text)
     token = None
@@ -317,7 +317,8 @@ if __name__ == "__main__":
     print("expression_dict {}".format(exp.expression_dict))
     print("inverse_polish_expressoin {}".format(exp.inverse_polish_expressoin))
     context = {
-        "10A": True,
+        "1A": True,
+        "2B": True,
     }
     print("result {}".format(exp.execute(context)))
     
\ No newline at end of file
